@@ -16,6 +16,18 @@ API Documentaton v2: https://t3n.zendesk.com/categories/20067994-API-v2-0-Beta-
 
 """
 
+from clc.APIv2.account import Account
+from clc.APIv2.group import Group
+from clc.APIv2.server import Servers, Server
+from clc.APIv2.network import Networks, Network
+from clc.APIv2.template import Templates, Template
+from clc.APIv2.alert import Alerts, Alert
+from clc.APIv2.queue import Queue, Request, Requests
+from clc.APIv2.anti_affinity import AntiAffinity
+from clc.APIv2.datacenter import Datacenter
+from clc.APIv2.api import API
+import clc.APIv2.time_utils
+
 
 ####### module/object vars #######
 V2_API_USERNAME = False
