@@ -19,13 +19,14 @@ Server object variables:
 	server.name
 	server.os
 	server.os_type
-	server.status
+	server.status - active, archived
 	server.type
 	server.storage_type
 	server.in_maintenance_mode
 	server.reserved_drive_paths
 	server.adding_cpu_requires_reboot
 	server.adding_memory_requires_reboot
+	server.dirty - bool indicating whether server object is different than cloud object
 
 Server object variables available but access subject to change with future releases:
 
@@ -40,12 +41,12 @@ Server object variables available but access subject to change with future relea
 # TODO - Link to Public IP class
 
 # vNext:
+# TODO - Restore archived server - need API spec
 # TODO - cpuAutoscalePolicy - need API spec 404
 # TODO - AntiAffinity policy - need API spec put call 400 
 # TODO - Statistics - need API spec get call 500
 # TODO - Billing (server, group, account) - need API spec
 # TODO - Server pricing (/v2/billing/btdi/serverPricing/wa1btdiapi207) returns array with static hourly pricing
-# TODO - Change Server (Update) - need API spec
 # TODO - Validation tasks with Server.Create
 # TODO - create server capture and resolve alias via uuid
 # TODO - Scheduled activities
@@ -125,6 +126,7 @@ class Servers(object):
 			return(clc.v2.Requests(e.response_json,alias=self.alias))
 
 
+	def Archive(self):  return(self._Operation('archive'))
 	def Pause(self):  return(self._Operation('pause'))
 	def ShutDown(self):  return(self._Operation('shutDown'))
 	def Reboot(self):  return(self._Operation('reboot'))
@@ -161,6 +163,7 @@ class Server(object):
 
 		self.id = id
 		self.capabilities = None
+		self.dirty = False
 
 		if alias:  self.alias = alias
 		else:  self.alias = clc.v2.Account.GetAlias()
@@ -168,12 +171,26 @@ class Server(object):
 		if server_obj:  self.data = server_obj
 		else:  
 			try:
-				self.data = clc.v2.API.Call('GET','servers/%s/%s' % (self.alias,self.id),{})
+				self.Refresh()
 			except clc.APIFailedResponse as e:
 				if e.response_status_code==404:  raise(clc.CLCException("Server does not exist"))
 
-		# API call switches between GB and MB.  Change to all references are in GB and we drop the units
-		self.data['details']['memoryGB'] = int(math.floor(self.data['details']['memoryMB']/1024))
+
+	def Refresh(self):
+		"""Reloads the server object to synchronize with cloud representation.
+
+		>>> clc.v2.Server("CA3BTDICNTRLM01").Refresh()
+
+		"""
+
+		self.dirty = False
+		self.data = clc.v2.API.Call('GET','servers/%s/%s' % (self.alias,self.id),{})
+
+		try:
+			# API call switches between GB and MB.  Change to all references are in GB and we drop the units
+			self.data['details']['memoryGB'] = int(math.floor(self.data['details']['memoryMB']/1024))
+		except:
+			pass
 
 
 	def _Capabilities(self,cached=True):
@@ -257,6 +274,7 @@ class Server(object):
 			return(clc.v2.Requests(e.response_json,alias=self.alias))
 
 
+	def Archive(self):  return(self._Operation('archive'))
 	def Pause(self):  return(self._Operation('pause'))
 	def ShutDown(self):  return(self._Operation('shutDown'))
 	def Reboot(self):  return(self._Operation('reboot'))
@@ -267,6 +285,19 @@ class Server(object):
 	def StopMaintenance(self):  return(self._Operation('stopMaintenance'))
 
 
+	def Restore(self):
+		"""Restore archived server to running state.
+
+		If server is already running returns with no change.
+
+		# {u'href': u'/v2/servers/btdi/wa1btdichange01/restore',
+		# u'rel': u'restore'},
+		#if status !== "archived": pass
+
+		"""
+
+
+
 	def ExecutePackage(self,package_id,parameters={}):
 		"""Execute an existing Bluerprint package on the server.
 
@@ -356,7 +387,7 @@ class Server(object):
 
 
 	@staticmethod
-	def Create(name,cpu,memory,template,group_id,network_id,alias=None,password=None,ip_address=None,
+	def Create(name,template,group_id,network_id,cpu=None,memory=None,alias=None,password=None,ip_address=None,
 	           storage_type="standard",type="standard",primary_dns=None,secondary_dns=None,
 			   additional_disks=[],custom_fields=[],ttl=None,managed_os=False,description=None,
 			   source_server_password=None,cpu_autoscale_policy_id=None,anti_affinity_policy_id=None,
@@ -365,6 +396,9 @@ class Server(object):
 
 		https://t3n.zendesk.com/entries/59565550-Create-Server
 
+		cpu and memory are optional and if not provided we pull from the default server size values associated with
+		the provided group_id.
+
 		Set ttl as number of seconds before server is to be terminated.  Must be >3600
 
 		>>> d = clc.v2.Datacenter()
@@ -377,6 +411,13 @@ class Server(object):
 
 		if not alias:  alias = clc.v2.Account.GetAlias()
 
+		if not cpu or not memory:
+			group = clc.v2.Group(id=group_id,alias=alias)
+			if not cpu and group.Defaults("cpu"):  cpu = group.Defaults("cpu")
+			elif not cpu:  raise(clc.CLCException("No default CPU defined"))
+
+			if not memory and group.Defaults("memory"):  memory = group.Defaults("memory")
+			elif not memory:  raise(clc.CLCException("No default Memory defined"))
 		if not description:  description = name
 		if type.lower() not in ("standard","hyperscale"):  raise(clc.CLCException("Invalid type"))
 		if storage_type.lower() not in ("standard","premium"):  raise(clc.CLCException("Invalid storage_type"))
@@ -455,18 +496,54 @@ class Server(object):
 		return(sum(requests_lst))
 
 
-	def Update(self):
-		"""Update group
+	def Change(self,cpu=None,memory=None,description=None,group_id=None):
+		"""Change existing server object.
 
-		*TODO* API not yet documented
+		One more more fields can be set and method will return with a requests
+		object for all queued activities.  This is a convenience function - all
+		each of these changes requires a seperate API call.  Some API calls are synchronous
+		(e.g. changing group ID or password) while others are async.
 
 		"""
 
-		#return(clc.v2.Requests(clc.v2.API.Call('PATCH','servers/%s/%s' % (self.alias,self.id),
-		#         json.dumps({'description': 'new'}),debug=True)))
+		if group_id:  groupId = group_id
+		else:  groupId = None
 
-		raise(Exception("Not implemented"))
+		payloads = []
+		requests = []
 
+		for key in ("cpu","memory","description","groupId"):
+			if key:  
+				requests.append(clc.v2.Requests(clc.v2.API.Call('PATCH','servers/%s/%s' % (self.alias,self.id), 
+				                                                json.dumps([{"op": "set", "member": key, "value": locals()[key]}]))))
+
+		if len(requests):  self.dirty = True
+
+		return(sum(requests))
+
+
+	def SetCPU(self,value):  return(self.Change(cpu=value))
+	def SetMemory(self,value):  return(self.Change(memory=value))
+	def SetDescription(self,value):  return(self.Change(description=value))
+	def SetGroup(self,group_id):  return(self.Change(group_id=group_id))
+
+
+	def SetPassword(self,password):  
+		"""Request change of password.
+
+		The API request requires supplying the current password.  For this we issue a call
+		to retrieve the credentials so note there will be an activity log for retrieving the
+		credentials associated with any SetPassword entry
+
+		>>> s.SetPassword("newpassword")
+
+		"""
+
+		# 0: {op: "set", member: "password", value: {current: " r`5Mun/vT:qZ]2?z", password: "Savvis123!"}}
+		if self.state != "active":  raise(clc.CLCException("Server must be powered on to change password"))
+
+		return(clc.v2.Requests(clc.v2.API.Call('PATCH','servers/%s/%s' % (self.alias,self.id), 
+		                                       json.dumps([{"op": "set", "member": "password", "value": {"current": self.Credentials()['password'], "password": password}}]),debug=True)))
 
 
 	def Delete(self):
